@@ -2,23 +2,25 @@
 """Client for motionEye."""
 from __future__ import annotations
 
-import aiohttp  # type: ignore
 import hashlib
-import logging
 import json
+import logging
+from pathlib import PurePath
+from types import TracebackType
 from typing import Any
+from urllib.parse import urlencode, urljoin, urlsplit, urlunsplit
+
+import aiohttp  # type: ignore
+
 from . import utils
 from .const import (
     DEFAULT_ADMIN_USERNAME,
-    DEFAULT_URL_SCHEME,
     DEFAULT_SURVEILLANCE_USERNAME,
+    DEFAULT_URL_SCHEME,
+    KEY_ID,
     KEY_STREAMING_PORT,
     KEY_VIDEO_STREAMING,
-    KEY_ID,
 )
-from urllib.parse import urlencode, urljoin, urlsplit, urlunsplit
-from types import TracebackType
-
 
 _LOGGER = logging.getLogger(__name__)
 
@@ -43,6 +45,10 @@ class MotionEyeClientURLParseError(MotionEyeClientError):
     """Unable to parse the URL."""
 
 
+class MotionEyeClientPathError(MotionEyeClientError):
+    """Invalid path provided."""
+
+
 class MotionEyeClient:
     """MotionEye Client."""
 
@@ -55,10 +61,11 @@ class MotionEyeClient:
         surveillance_password: str | None = None,
     ):
         """Construct a new motionEye client."""
-        if not url.lower().startswith("http://") and not url.lower().startswith(
-            "https://"
-        ):
-            url = f"{DEFAULT_URL_SCHEME}://" + url
+        parsed = urlsplit(url)
+        if not parsed.scheme or not parsed.netloc:
+            raise MotionEyeClientURLParseError(
+                "Invalid URL, must have a URL scheme and host: %s" % url
+            )
 
         self._url = url
         self._session = aiohttp.ClientSession()
@@ -165,12 +172,10 @@ class MotionEyeClient:
 
     async def async_client_login(self) -> dict[str, Any] | None:
         """Login to the motionEye server."""
-
         return await self._async_request("/login")
 
     async def async_client_close(self) -> bool:
         """Disconnect to the MotionEye server."""
-
         await self._session.close()
         return True
 
@@ -217,15 +222,12 @@ class MotionEyeClient:
             and camera.get(KEY_VIDEO_STREAMING, False)
         )
 
-    def get_camera_steam_url(self, camera: dict[str, Any]) -> str | None:
+    def get_camera_stream_url(self, camera: dict[str, Any]) -> str | None:
         """Get the camera stream URL."""
         if MotionEyeClient.is_camera_streaming(camera):
-            # Attempt to extract the hostname from the URL (removing the port if present)
+            # Extract the hostname from the URL (removing the port if present)
+            # Url validity is checking on construction so this will always succeed.
             host = urlsplit(self._url).netloc.split(":")[0]
-            if not host:
-                raise MotionEyeClientURLParseError(
-                    f"Could not extract hostname from {self._url}."
-                )
 
             # motion (the process underlying motionEye) cannot natively do https on the
             # stream port, it will always be http regardless of what protocol is used to
@@ -245,14 +247,45 @@ class MotionEyeClient:
         """Get the camera stream URL."""
         if not MotionEyeClient.is_camera_streaming(camera) or KEY_ID not in camera:
             return None
-        snapshot_url = urljoin(
-            self._url,
-            f"/picture/{camera[KEY_ID]}/current/?_username={self._surveillance_username}",
+        return self._build_url(
+            urljoin(
+                self._url,
+                f"/picture/{camera[KEY_ID]}/current/",
+            ),
+            admin=False,
         )
-        snapshot_url += "&_signature=" + utils.compute_signature_from_password(
-            "GET",
-            snapshot_url,
-            None,
-            self._surveillance_password,
+
+    def _strip_leading_slash(self, path: str) -> str:
+        """Strip leading slash from a path."""
+        pure_path = PurePath(path)
+        if not pure_path.parts:
+            raise MotionEyeClientPathError("Could not parse empty path")
+        if pure_path.parts[0] == "/":
+            path = str(PurePath(*pure_path.parts[1:]))
+        return path
+
+    def get_movie_url(self, camera_id: int, path: str) -> str:
+        """Get the movie playback URL."""
+        return self._build_url(
+            urljoin(
+                self._url,
+                f"/movie/{camera_id}/playback/{self._strip_leading_slash(path)}",
+            )
         )
-        return snapshot_url
+
+    def get_image_url(self, camera_id: int, path: str) -> str:
+        """Get the image URL."""
+        return self._build_url(
+            urljoin(
+                self._url,
+                f"/picture/{camera_id}/download/{self._strip_leading_slash(path)}",
+            )
+        )
+
+    async def async_get_movies(self, camera_id: int) -> dict[str, Any] | None:
+        """Get a motionEye camera config."""
+        return await self._async_request(f"/movie/{camera_id}/list")
+
+    async def async_get_images(self, camera_id: int) -> dict[str, Any] | None:
+        """Get a motionEye camera config."""
+        return await self._async_request(f"/picture/{camera_id}/list")
