@@ -1,35 +1,39 @@
 """Constants for motionEye client."""
-DEFAULT_URL_SCHEME = "http"
-DEFAULT_PORT = 8765
 DEFAULT_ADMIN_USERNAME = "admin"
+DEFAULT_PORT = 8765
+DEFAULT_URL_SCHEME = "http"
 DEFAULT_SURVEILLANCE_USERNAME = "user"
 
 KEY_CAMERAS = "cameras"
 KEY_ERROR = "error"
-KEY_NAME = "name"
 KEY_ID = "id"
-KEY_VIDEO_STREAMING = "video_streaming"
+KEY_MEDIA_LIST = "mediaList"
+KEY_MIME_TYPE = "mimeType"
+KEY_MOTION_DETECTION = "motion_detection"
+KEY_MOVIES = "movies"
+KEY_NAME = "name"
+KEY_PATH = "path"
+KEY_STILL_IMAGES = "still_images"
 KEY_STREAMING_PORT = "streaming_port"
 KEY_STREAMING_AUTH_MODE = "streaming_auth_mode"
-KEY_MOTION_DETECTION = "motion_detection"
 KEY_TEXT_OVERLAY = "text_overlay"
-KEY_TEXT_OVERLAY_LEFT = "left_text"
-KEY_TEXT_OVERLAY_RIGHT = "right_text"
-KEY_TEXT_OVERLAY_DISABLED = "disabled"
-KEY_TEXT_OVERLAY_TIMESTAMP = "timestamp"
 KEY_TEXT_OVERLAY_CAMERA_NAME = "camera-name"
 KEY_TEXT_OVERLAY_CUSTOM_TEXT = "custom-text"
 KEY_TEXT_OVERLAY_CUSTOM_TEXT_LEFT = "custom_left_text"
 KEY_TEXT_OVERLAY_CUSTOM_TEXT_RIGHT = "custom_right_text"
-KEY_STILL_IMAGES = "still_images"
-KEY_MOVIES = "movies"
+KEY_TEXT_OVERLAY_DISABLED = "disabled"
+KEY_TEXT_OVERLAY_LEFT = "left_text"
+KEY_TEXT_OVERLAY_RIGHT = "right_text"
+KEY_TEXT_OVERLAY_TIMESTAMP = "timestamp"
+KEY_UPLOAD_ENABLED = "upload_enabled"
+KEY_VIDEO_STREAMING = "video_streaming"
 
 KEY_WEB_HOOK_NOTIFICATIONS_ENABLED = "web_hook_notifications_enabled"
-KEY_WEB_HOOK_NOTIFICATIONS_URL = "web_hook_notifications_url"
 KEY_WEB_HOOK_NOTIFICATIONS_HTTP_METHOD = "web_hook_notifications_http_method"
-KEY_WEB_HOOK_STORAGE_URL = "web_hook_storage_url"
+KEY_WEB_HOOK_NOTIFICATIONS_URL = "web_hook_notifications_url"
 KEY_WEB_HOOK_STORAGE_ENABLED = "web_hook_storage_enabled"
 KEY_WEB_HOOK_STORAGE_HTTP_METHOD = "web_hook_storage_http_method"
+KEY_WEB_HOOK_STORAGE_URL = "web_hook_storage_url"
 
 KEY_HTTP_METHOD_GET = "GET"
 
@@ -91,7 +95,6 @@ KEY_WEB_HOOK_CONVERSION_SPECIFIERS = {
     KEY_WEB_HOOK_CS_MOTION_VERSION: r"%{ver}",
 }
 
-
 KEY_ACTION_SNAPSHOT = "snapshot"
 KEY_ACTION_RECORD_START = "record_start"
 KEY_ACTION_RECORD_STOP = "record_stop"
